<footer class="mdl-mini-footer">
    <div class="mdl-mini-footer__left-section">
      <div class="mdl-logo">{{ project }}</div>
      <div>
        {% set toctree = toctree(maxdepth=1, collapse=False, includehidden=False, titles_only=False) %}
        {{ toctree }}
      </div>
    </div>

    <div class="mdl-mini-footer__right-section">
    {%- if show_copyright %}
      {%- if hasdoc('copyright') %}
        <div>{% trans path=pathto('copyright'), copyright=copyright|e %}&copy; <a href="{{ path }}">Copyright</a> {{ copyright }}.{% endtrans %}</div>
      {%- else %}
        <div>{% trans copyright=copyright|e %}&copy; Copyright {{ copyright }}.{% endtrans %}</div>
      {%- endif %}
    {%- endif %}
    {%- if last_updated %}
      <div>{% trans last_updated=last_updated|e %}Last updated on {{ last_updated }}.{% endtrans %}</div>
    {%- endif %}
    </div>
</footer>
